## 2.10.2 (2021-12-28)

Use PEP 585 syntax wherever possible (#6717)

## 2.10.1 (2021-12-17)

Use stubtest 0.920 (#6589)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>
Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>
Co-authored-by: Sebastian Rittau <srittau@rittau.biz>
Co-authored-by: Akuli <akuviljanen17@gmail.com>

## 2.10.0 (2021-12-09)

Add stubs for hdbcli (#6550)

hdbcli is the python dbapi for SAP HANA. Not all methods/attributes are 100% compatible with PEP 249.

